==> camel-core-2.15-20150307.023702-161-sources.jar: org/apache/camel/model/language/ExchangePropertyExpression.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model.language;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.spi.Metadata;

/**
 * An expression which extracts the named exchange property
 *
 * @version 
 */
@Metadata(label = "language")
@XmlRootElement(name = "exchangeProperty")
@XmlAccessorType(XmlAccessType.FIELD)
public class ExchangePropertyExpression extends ExpressionDefinition {

    public ExchangePropertyExpression() {
    }

    public ExchangePropertyExpression(String expression) {
        super(expression);
    }

    public String getLanguage() {
        return "exchangeProperty";
    }
}

==> camel-core-2.16-20150815.030037-138-sources.jar: org/apache/camel/model/language/ExchangePropertyExpression.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model.language;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.apache.camel.spi.Metadata;

/**
 * An expression which extracts the named exchange property
 *
 * @version 
 */
@Metadata(label = "language", title = "ExchangeProperty")
@XmlRootElement(name = "exchangeProperty")
@XmlAccessorType(XmlAccessType.FIELD)
public class ExchangePropertyExpression extends ExpressionDefinition {

    public ExchangePropertyExpression() {
    }

    public ExchangePropertyExpression(String name) {
        super(name);
    }

    public String getLanguage() {
        return "exchangeProperty";
    }
}
